# sha-python-devtools


[![PyPI version](https://badge.fury.io/py/sha-python-devtools.svg)](https://badge.fury.io/py/sha-python-devtools)
![versions](https://img.shields.io/pypi/pyversions/sha-python-devtools.svg)
[![GitHub license](https://img.shields.io/github/license/mgancita/sha-python-devtools.svg)](https://github.com/mgancita/sha-python-devtools/blob/main/LICENSE)


[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


Python的开发工具，便于调试。

## 来自
来自python-devtools 工具，准备用来进行自定义操作。

## 版本

v0.1.5 修改`timer.py` `def __enter__(self) ->Timer`  解决 `name 'Timer' is not defined` 问题。

- 开源许可: MIT
- 文档: https://llango.github.io/sha-python-devtools.


## 特征

* TODO

## 制作


该包使用 [Cookiecutter](https://github.com/audreyr/cookiecutter) 和 [`llango/cookiecutter-mkdoc-shapackage`](https://github.com/llango/cookiecutter-mkdoc-shapackage/) 项目模版创建。
